EvStripe
========

Plugin for taking Stripe payments using EvTransactions.

Usage
-----

When using Stripe all card data is submitted directly to the payment gateway and not via the website's server. This is handled using some JavaScript supplied by Stripe that generates a token that is then submitted to the website's server for processing the payment. So on your payment page you need to include the JS which is done using the `stripejs` element:-

	<?= $this->element('EvStripe.stripejs') ?>

If you want to customise the script for handling the communication between the website and Stripe
then override the `webroot/js/stripe.js` file.

Make sure you also load the Stripe component in your controller so that the Stripe JS is set up with the correct key:-

	$this->loadComponent('EvStripe.Stripe');

An example payment form has been included that can be used directly or just as a guide. This can be found in `View/Elements/payment_form.ctp`. It's important that the form inputs aren't named so that they don't submit card details to the server and that they use the `data-stripe` attributes.

You will need to configure the plugin in `Config/Plugin/ev_transactions.php` and it should look something like:-

	$config = [
		'EvTransactions' => [
			'gateway' => 'EvStripe.Stripe',
			'currency' => 'gbp',
			'stripe' => [
				'live' => [
					'secret_key' => 'to-be-provided-by-client',
					'publishable_key' => 'to-be-provided-by-client'
				],
				'dev' => [
					'secret_key' => 'sk_test_5Z0SK51oEvPlaRkh6wKFJ7Gu',
					'publishable_key' => 'pk_test_oTLrM7uYObyZd3BtBIX61mg1'
				]
			]
		]
	];

When you take payment using EvTransactions' `Transactions::takePayment()` it will return the payment response to determine if successful payment has been taken or not rather than `processReturn()`.

This plugin uses OmniPay.
